@@ -364,7 +364,7 @@ class Data:
     cl_name = {'value':'calculate-server'}
 
     # версия программы
-    cl_ver = {'value':'2.1.9'}
+    cl_ver = {'value':'2.1.10'}
 
     #DN LDAP ветки, в котором будут находится служебные ветки
     ld_ldap_dn = {}
@@ -466,13 +466,3 @@ class Data:
     #Настроен или нет сервис DHCP
     sr_dhcp_set = {'mode':"w",
                    'value':'off'}
-
-    #-----------------------------------------------------
-    # Управление сервисами ~/.calculate.env
-    #-----------------------------------------------------
-    # хеш пароля пользователя для сервиса Unix
-    ur_unix_hash = {'mode':"w"}
-    # LANMAN хеш пароля пользователя для сервиса Samba
-    ur_samba_lm_hash = {'mode':"w"}
-    # NT хеш пароля пользователя для сервиса Samba
-    ur_samba_nt_hash = {'mode':"w"}
\ No newline at end of file
